==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/sw.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kusimamia Lightbox Gallary Vigezo");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "kusimamia Nyumba ya sanaa");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image upana");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Urefu");
define('MANAGE_GALLERY_THUMB_WIDTH', "Picha ndogo upana Image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Picha ndogo Image Urefu");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Kuhifadhi Thumb Mgao");
define('MANAGE_GALLERY_SHOW_TITLES', "show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Aina");
define('MANAGE_GALLERY_DELETE_IMAGE', "kufuta Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Ila Aina Agizo");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click &#39;Mwisho&#39; kuchapisha <br /> picha yako uploaded.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Picha zote wamekuwa resized na mazingira mmeokolewa.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Kulikuwa na hitilafu resizing picha au kuokoa mazingira.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "picha yako (s) imekuwa uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Kulikuwa na hitilafu ya kupakia picha yako (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "faili unayojaribu kupakia si picha.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "faili unayojaribu kupakia ni kubwa mno.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "kichwa umehifadhiwa.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Je, una uhakika unataka kufuta picha");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "picha umefutwa.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Kulikuwa na hitilafu ya kufuta picha.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Kuokoa vigezo na resizing picha, tafadhali kusubiri ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Kuweka, tafadhali kusubiri ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "aina ili haijawahi kuokolewa. Je, unataka kuokoa aina ili?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ili picha aina umehifadhiwa.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Kulikuwa na hitilafu kuhifadhi picha namna yo yote.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sw.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kusimamia Lightbox Gallary Vigezo");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "kusimamia Nyumba ya sanaa");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image upana");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Urefu");
define('MANAGE_GALLERY_THUMB_WIDTH', "Picha ndogo upana Image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Picha ndogo Image Urefu");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Kuhifadhi Thumb Mgao");
define('MANAGE_GALLERY_SHOW_TITLES', "show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Aina");
define('MANAGE_GALLERY_DELETE_IMAGE', "kufuta Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Ila Aina Agizo");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click &#39;Mwisho&#39; kuchapisha <br /> picha yako uploaded.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Picha zote wamekuwa resized na mazingira mmeokolewa.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Kulikuwa na hitilafu resizing picha au kuokoa mazingira.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "picha yako (s) imekuwa uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Kulikuwa na hitilafu ya kupakia picha yako (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "faili unayojaribu kupakia si picha.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "faili unayojaribu kupakia ni kubwa mno.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "kichwa umehifadhiwa.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Je, una uhakika unataka kufuta picha");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "picha umefutwa.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Kulikuwa na hitilafu ya kufuta picha.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Kuokoa vigezo na resizing picha, tafadhali kusubiri ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Kuweka, tafadhali kusubiri ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "aina ili haijawahi kuokolewa. Je, unataka kuokoa aina ili?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ili picha aina umehifadhiwa.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Kulikuwa na hitilafu kuhifadhi picha namna yo yote.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Faili unayojaribu kupakia ni kubwa kuliko mipangilio ya &#39;upload_max_filesize&#39; au mipangilio ya &#39;post_max_size&#39; PHP. Wasiliana na msimamizi wa mfumo wako ili kuongeza mipaka hii.");
?>
